from datetime import datetime

BABY_BLUE = "#89CFF0"
VALENTINE_PINK = "#e8456b"
VALENTINE_ROSE = "#d43a5c"
DIM_BLUE = "#4a6a80"
DIM_TEXT = "#555560"
DEFAULT_TEXT = "#c8c8d0"
START_DATE = datetime(2023, 4, 1)

COLOR_POOL = [
    BABY_BLUE,
    VALENTINE_PINK,
    "#b48ecc",
    "#7eb8da",
    VALENTINE_ROSE,
    "#a8d0e6",
    "#c9779e",
    "#d4a0b9",
    "#7ca7c4",
    "#9fc1d9",
]

SONNET_116 = [
    "Let me not to the marriage of true minds",
    "Admit impediments. Love is not love",
    "Which alters when it alteration finds,",
    "Or bends with the remover to remove.",
    "O no! it is an ever-fixed mark",
    "That looks on tempests and is never shaken;",
    "It is the star to every wand'ring bark,",
    "Whose worth's unknown, although his height be taken.",
    "Love's not Time's fool, though rosy lips and cheeks",
    "Within his bending sickle's compass come;",
    "Love alters not with his brief hours and weeks,",
    "But bears it out even to the edge of doom.",
    "  If this be error and upon me prov'd,",
    "  I never writ, nor no man ever lov'd.",
]

ASCII_LOVEBIRDS = [
    '                 _  _',
    '                ( \\/ )',
    '         .---.   \\  /   ."-.\"',
    '        /   6_6   \\/   / 4 4 \\',
    '        \\_  (__\\       \\_ v _/',
    '        //   \\\\        //   \\\\',
    '       ((     ))      ((     ))',
    '  =====""===""========""===""=======',
    '          |||            |||',
    '           |              |',
]

ASCII_HEART = [
    "  **   **",
    " **** ****",
    " *********",
    "  *******",
    "   *****",
    "    ***",
    "     *",
]
